
import typer, os

from typing import Optional
from frenchmaid import __app_name__, __version__, delcache

app = typer.Typer()

def _version_callback(value: bool) -> None:
    if value:
        typer.echo(f"{__app_name__} v{__version__}")
        raise typer.Exit()

@app.callback()
def main(
    version: Optional[bool] = typer.Option(
        None,
        "--version",
        "-v",
        help="View the CLI version and stuff... maybe",
        callback=_version_callback,
        is_eager=True
    )
) -> None: return

@app.command()
def clean():
    dirdir = os.getcwd()
    delcache.pyCacheOnly(dirdir)
    raise typer.Exit()


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="frenchmaid",
    version="0.1.2",
    description="Remove all pests from your project! frenchmaid is a lightweight all platform cli package that will delete all __pycache__ folders (contents included) in your project directory. Are you tired of doing it manually each time? Fear not, the frenchmaid will do it for you!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lewisjr/frenchmaid.git",
    project_urls={
        "Bug Tracker": "https://github.com/lewisjr/frenchmaid/issues",
    },
    author = "Techtronics Solutions Limited | Lewis Mosho Jr",
    author_email = "lmosho@techtronicsltd.com",
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Utilities",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",

    ],
    packages=["frenchmaid"],
    include_package_data=True,
    install_requires=["click", "colorama", "typer"],
    entry_points={
        "console_scripts": [
            "frenchmaid=frenchmaid.__main__:main",
        ]
    },
    package_dir={"": "src"},
    python_requires=">=3.0",
)


import os, shutil, sys

platf = sys.platform

def openDirs(dir_loop):
    try:
        return os.getcwd(dir_loop)
    except:
        return False

def delDir(dir_select):
    try:
        shutil.rmtree(dir_select)
        return True
    except:
        return False

def loopDirs(main_dir, dir_arr, num_pycache, dir_arr_used):
    iterats = num_pycache
    arr = dir_arr_used
    arr2 = dir_arr_used

    if "pyvenv.cfg" not in dir_arr:
        for dir in dir_arr:
            if (dir in dir_arr_used) == False:
                if str(dir) == "__pycache__":

                    if platf == "win32":
                        arr.append(f"{main_dir}\\{dir}")
                    else:
                        arr2.append(f"{main_dir}/{dir}")

                    iterats += 1
                elif str(dir) != "__pycache__":

                    if platf == "win32":
                        other_dir = f"{main_dir}\\{dir}"
                    else:
                        other_dir = f"{main_dir}/{dir}"

                    try:
                        other_dirs = os.listdir(other_dir)

                        if platf == "win32":
                            iterats_two = loopDirs(other_dir, other_dirs, iterats, arr)
                        else:
                            iterats_two = loopDirs(other_dir, other_dirs, iterats, arr)

                        iterats = iterats + iterats_two
                    except:
                        iterats = iterats


    if platf == "win32":
        return arr
    else:
        return arr2

def pyCacheOnly(dir_main):
    try:
        
        if platf == "win32":
            dir_name = str(dir_main)[str(dir_main).rfind("\\")+1:len(dir_main)]
        else:
            dir_name = str(dir_main)[str(dir_main).rfind("/")+1:len(dir_main)]
            
        dirs = os.listdir(dir_main)
        num_dirs = len(dirs)
        arr = []

        array_thing = loopDirs(dir_main, dirs, 0, arr)
        res = len(array_thing)
        
        for official_dir in array_thing:
            delDir(official_dir)

        if res == 0:
            print(f'''\nThere are no pests in your "{dir_name}" directory!''')
            return False
        else:
            print(f'\nSuccesfully found {res} pest(s) in {num_dirs} directories and/or files contained within your "{dir_name}" directory. They have been eradicated!\n')

    except Exception as e:
        print('\nflail')
        print(e)
        print('\n')
        return False